import { useAjax } from "@/Hook/useAjax"
import { cutPutApi } from "@/services/operating/accountyyb"
import { Form, message, Modal, Select } from "antd"
import React, { useEffect, useState } from "react"


interface Props {
    allOfMember: any
    onChange?: () => void
    onClose?: () => void
    visible?: boolean,
    value?: any
}

/**
 * 指派
 * @param props 
 * @returns 
 */
const AppointPut: React.FC<Props> = (props) => {
    /*******************************/
    const { onChange, onClose, visible, allOfMember, value } = props
    const [userAll, setUserAll] = useState([])

    const [form] = Form.useForm();
    const cutPut = useAjax((params) => cutPutApi(params))
    /*******************************/

    useEffect(() => {
        if (value && Object.keys(value).length > 0) {
            form.setFieldsValue({ putUserId: value.putUserId })
        }
    }, [value])

    /** 获取组员 */
    useEffect(() => {
        (async function () {
            let res = allOfMember?.data || await allOfMember.run()
            if (res?.data) {
                let useAll: any = []
                res?.data?.forEach((item: { key: { userId: any; nickName: any; }; value: any[]; }) => {
                    let obj = {
                        key: item.key.userId,
                        label: item.key.nickName
                    }
                    if (item?.value) {
                        obj['childrenarr'] = item?.value?.map(item => {
                            return { key: item.accountId + '_' + item.id, label: item?.remark ? item.accountId + '_' + item?.remark : item.accountId }
                        })
                    }
                    useAll.push(obj)
                })
                setUserAll(useAll)
            }
        })()
    }, [])

    const handleOk = () => {
        form.validateFields().then(values => {
            cutPut.run({ ...values, accountIds: [value.accountId] }).then(res => {
                message.success('指派成功')
                onChange?.()
            })
        })
    }

    return <Modal
        title="指派"
        visible={visible}
        onOk={handleOk}
        onCancel={() => onClose?.()}
        confirmLoading={cutPut.loading}
    >
        <Form
            form={form}
            labelCol={{ span: 4 }}
            colon={false}
            initialValues={{}}
        >
            <Form.Item label={<strong>组员</strong>} name='putUserId' rules={[{ required: true, message: '请选择分组' }]}>
                <Select
                    placeholder='请选择组员'
                    showSearch
                    filterOption={(input: string, option: any) => {
                        return option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }}
                >
                    {userAll?.map((item: { key: string, label: number }) => <Select.Option value={item.key} key={item.key}>{item.label}</Select.Option>)}
                </Select>
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(AppointPut)